<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use App\Models\Transaction;
use App\Models\User;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Log;
use Illuminate\Support\Facades\DB;
use Carbon\Carbon;

class BinaryCommissionController extends Controller
{
    /**
     * Display Binary Commission Report.
     */
    public function index()
    {
        $pageTitle = 'Manage Binary Commission';

        // Fetch commission rates
        $commissionRates = config('binary_commission.rates', [
            1 => 10, 2 => 8, 3 => 6, 4 => 5, 5 => 4,
            6 => 3, 7 => 2, 8 => 2, 9 => 1, 10 => 1
        ]);

        // Fetch minimum purchase value from settings table
        $binaryCommissionMinimumPurchase = DB::table('settings')
            ->where('key', 'binary_commission_minimum_purchase')
            ->value('value') ?? 50; // Default to 50 if not found

        // Fetch commission transactions
        $commissions = Transaction::where('remark', 'binary_commission')
            ->with('user:id,username,email') 
            ->latest()
            ->paginate(10);

        // Fetch users for dropdown
        $users = User::select('id', 'username')->get();

        return view('admin.binary_commission.index', compact(
            'pageTitle', 
            'commissions', 
            'users', 
            'commissionRates', 
            'binaryCommissionMinimumPurchase'
        ));
    }

    /**
     * Store a new Binary Commission Entry (Manual Entry).
     */
    public function store(Request $request)
    {
        $request->validate([
            'user_id' => 'required|exists:users,id',
            'amount' => 'required|numeric|min:0.01',
        ]);
    
        $user = User::find($request->user_id);
    
        if (!$user) {
            return back()->withErrors(['user_id' => 'User not found.']);
        }
    
        DB::transaction(function () use ($user, $request) {
            // Insert commission transaction
            Transaction::create([
                'user_id' => $user->id,
                'amount' => $request->amount,
                'remark' => 'binary_commission',
                'created_at' => now(),
                'updated_at' => now()
            ]);
    
            // ✅ Ensure balance updates correctly
            $user->increment('balance', $request->amount);
            $user->increment('total_binary_com', $request->amount);
        });
    
        Log::info("✅ Manually added Binary Commission for User ID: " . $user->id . " | Amount: $" . $request->amount);
    
        return redirect()->route('binary-commission.index')->with('success', 'Binary Commission added successfully!');
    }

    /**
     * Automatically Calculate and Distribute Binary Commission.
     */
    public function calculateCommission()
    {
        Log::info("🔄 Starting Monthly Binary Commission Calculation");

        $commissionRates = config('binary_commission.rates', [
            1 => 10, 2 => 8, 3 => 6, 4 => 5, 5 => 4,
            6 => 3, 7 => 2, 8 => 2, 9 => 1, 10 => 1
        ]);

        $minimumPurchase = DB::table('settings')
            ->where('key', 'binary_commission_minimum_purchase')
            ->value('value') ?? 50;

        $currentMonth = Carbon::now()->format('Y-m');

        // Get all active users who made purchases this month
        $qualifiedUsers = User::whereHas('purchases', function ($query) use ($minimumPurchase, $currentMonth) {
            $query->where('total_amount', '>=', $minimumPurchase)
                ->where('created_at', 'like', "$currentMonth%");
        })->with(['purchases' => function ($query) use ($currentMonth) {
            $query->where('created_at', 'like', "$currentMonth%")->latest();
        }])->get();

        Log::info("✅ Found " . $qualifiedUsers->count() . " Eligible Users for Commission Calculation");

        DB::transaction(function () use ($qualifiedUsers, $commissionRates) {
            foreach ($qualifiedUsers as $user) {
                $this->distributeCommission($user, $commissionRates);
            }
        });

        Log::info("🎉 Monthly Binary Commission Calculation Completed");

        return back()->with('success', 'Binary Commissions have been calculated successfully.');
    }

    /**
     * Distribute commission based on generations and compression.
     */
   private function distributeCommission(User $user, $commissionRates)
{
    Log::info("🟢 Distributing Binary Commission for User ID: " . $user->id);

    $referrer = $user->referrer;
    $generation = 1;
    $latestPurchase = $user->purchases->first();

    if (!$latestPurchase) {
        Log::warning("⚠️ User ID: " . $user->id . " has no recent purchases. Skipping commission distribution.");
        return;
    }

    $purchaseAmount = $latestPurchase->total_amount;

    while ($referrer && $generation <= 10) {
        Log::info("🔵 Checking Referrer ID: " . $referrer->id . " | Generation: " . $generation);

        $isQualified = $referrer->purchases()
            ->where('total_amount', '>=', DB::table('settings')
            ->where('key', 'binary_commission_minimum_purchase')
            ->value('value') ?? 50)
            ->where('created_at', 'like', Carbon::now()->format('Y-m') . '%')
            ->exists();

        if ($isQualified) {
            $commissionPercentage = $commissionRates[$generation] ?? 0;
            $amount = ($purchaseAmount * $commissionPercentage) / 100;

            if ($amount > 0) {
                Log::info("🟡 Commission: Referrer ID: " . $referrer->id . " | Amount: $" . $amount . " | Gen: " . $generation);

                // Prevent duplicate commission for the same month
                $existingCommission = Transaction::where('user_id', $referrer->id)
                    ->where('remark', 'binary_commission')
                    ->where('created_at', 'like', Carbon::now()->format('Y-m') . '%')
                    ->exists();

                if (!$existingCommission) {
                    DB::transaction(function () use ($referrer, $amount) {
                        // ✅ Update User Balance and Total Binary Commission
                        $referrer->increment('balance', $amount);
                        $referrer->increment('total_binary_com', $amount);

                        // ✅ Insert Transaction
                        Transaction::create([
                            'user_id' => $referrer->id,
                            'amount' => $amount,
                            'post_balance' => $referrer->balance,  // Save post balance
                            'remark' => 'binary_commission',
                            'created_at' => now(),
                            'updated_at' => now()
                        ]);
                    });

                    Log::info("✅ Commission Successfully Assigned to User ID: " . $referrer->id . " and Balance Updated");
                } else {
                    Log::warning("⚠️ Skipping duplicate commission for Referrer ID: " . $referrer->id);
                }
            }
        } else {
            Log::warning("❌ Referrer ID: " . $referrer->id . " is NOT QUALIFIED, skipping.");
        }

        $referrer = $referrer->referrer;
        $generation++;
    }

    Log::info("✅ Commission Distribution Completed for User ID: " . $user->id);
    }
}