<?php 

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use Illuminate\Http\Request;
use App\Models\HouseFundWallet;
use App\Models\HouseFundContribution;
use App\Models\HouseFundRedemption;
use App\Models\User;
use App\Models\Setting;
use Illuminate\Support\Facades\DB;
use Illuminate\Support\Facades\Log;

class HouseFundController extends Controller
{
    /**
     * Display House Fund Wallet Dashboard for Admin.
     */
    public function index()
    {
        $pageTitle = 'Manage House Fund Wallet';
        $wallets = HouseFundWallet::with('user')->paginate(10);
        $totalHouseFundWallet = HouseFundWallet::sum('balance');

        return view('admin.house_fund_wallet.index', compact('pageTitle', 'wallets', 'totalHouseFundWallet'));
    }

    /**
     * View a specific user's wallet.
     */
    public function show($user_id)
    {
        $user = User::findOrFail($user_id);
        $wallet = HouseFundWallet::firstOrCreate(
            ['user_id' => $user_id],
            [
                'balance' => 0.00,
                'monthly_contribution' => 0.00,
                'redeem_threshold' => Setting::where('key', 'house_fund.redeem_threshold')->value('value') ?? 1000.00,
            ]
        );

        $contributions = HouseFundContribution::where('user_id', $user_id)->latest()->get();
        $redemptions = HouseFundRedemption::where('user_id', $user_id)->latest()->get();

        return view('admin.house_fund_wallet.show', compact('user', 'wallet', 'contributions', 'redemptions'));
    }

    /**
     * ✅ Approve a redemption request.
     */
    public function approveRedemption($id)
    {
        $redemption = HouseFundRedemption::findOrFail($id);
        $wallet = HouseFundWallet::where('user_id', $redemption->user_id)->first();
    
        if (!$wallet) {
            return response()->json(['error' => 'Wallet not found.'], 404);
        }
    
        if ($wallet->balance < $redemption->amount) {
            return response()->json(['error' => 'Insufficient balance for redemption.'], 400);
        }
    
        DB::beginTransaction();
        try {
            // Deduct from user wallet
            $wallet->decrement('balance', $redemption->amount);
            $redemption->update(['status' => 'approved']);
    
            // ✅ Update Total House Fund Wallet for the dashboard
            cache()->forget('total_house_fund_wallet');
            cache()->remember('total_house_fund_wallet', now()->addMinutes(10), function () {
                return HouseFundWallet::sum('balance');
            });
    
            DB::commit();
            return response()->json(['success' => true, 'message' => 'Redemption approved successfully!']);
        } catch (\Exception $e) {
            DB::rollBack();
            return response()->json(['error' => 'Error approving redemption: ' . $e->getMessage()], 500);
        }
    }

    /**
     * ✅ Reject a redemption request.
     */
    public function rejectRedemption($id)
    {
        try {
            $redemption = HouseFundRedemption::findOrFail($id);

            if ($redemption->status === 'approved') {
                return response()->json(['error' => '❌ Cannot reject an already approved redemption.'], 400);
            }

            $redemption->update(['status' => 'rejected']);

            return response()->json(['success' => true, 'message' => '❌ Redemption request rejected successfully.']);
        } catch (\Exception $e) {
            Log::error('Redemption Rejection Error: ' . $e->getMessage());
            return response()->json(['error' => '❌ Error rejecting redemption. Try again.'], 500);
        }
    }

    /**
     * ✅ Update House Fund Settings (Redemption Threshold & Percentage)
     */
    public function updateSettings(Request $request)
    {
        $validatedData = $request->validate([
            'redeem_threshold' => 'required|numeric|min:0',
            'house_fund_percentage' => 'required|numeric|min:0|max:100',
        ]);

        try {
            Setting::updateOrCreate(['key' => 'house_fund.redeem_threshold'], ['value' => $validatedData['redeem_threshold']]);
            Setting::updateOrCreate(['key' => 'house_fund.percentage'], ['value' => $validatedData['house_fund_percentage']]);

            return response()->json(['success' => true, 'message' => '✅ Settings updated successfully.']);
        } catch (\Exception $e) {
            Log::error('Settings Update Error: ' . $e->getMessage());
            return response()->json(['error' => '❌ Error updating settings. Try again.'], 500);
        }
    }

    /**
     * ✅ Update User's Wallet Balance
     */
    public function updateBalance(Request $request)
    {
        $validatedData = $request->validate([
            'user_id' => 'required|exists:users,id',
            'balance' => 'required|numeric|min:0'
        ]);

        try {
            $wallet = HouseFundWallet::where('user_id', $validatedData['user_id'])->first();

            if (!$wallet) {
                return response()->json(['error' => '❌ User wallet not found.'], 404);
            }

            $wallet->update(['balance' => $validatedData['balance']]);

            return response()->json([
                'success' => true,
                'message' => '✅ Balance updated successfully!',
                'updated_balance' => $wallet->balance
            ]);
        } catch (\Exception $e) {
            Log::error('Balance Update Error: ' . $e->getMessage());
            return response()->json(['error' => '❌ Error updating balance. Try again.'], 500);
        }
    }
}
