<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use Illuminate\Http\Request;
use App\Models\HouseFundWallet;
use App\Models\HouseFundContribution;
use App\Models\HouseFundRedemption;
use App\Models\User;
use Illuminate\Support\Facades\Session;

class HouseFundWalletController extends Controller
{
    /**
     * Display House Fund Wallet Dashboard for Admin.
     */
    public function index()
    {
        $pageTitle = 'House Fund Wallet';
    
        // Fetch unique remarks related to House Fund transactions
        $remarks = \App\Models\Transaction::where('remark', 'house_fund_wallet')
            ->distinct()
            ->pluck('remark');
    
        // Fetch total House Fund Wallet balance
        $totalHouseFundWallet = \App\Models\HouseFundWallet::sum('balance');
    
        // Get paginated House Fund Wallet records
        $wallets = \App\Models\HouseFundWallet::with('user')->paginate(10);
    
        // Pass data to view
        $widget = [
            'total_house_fund_wallet' => $totalHouseFundWallet
        ];
    
        return view('admin.house_fund_wallet.index', compact('pageTitle', 'wallets', 'widget', 'remarks'));
    }
    /**
     * View a specific user's wallet.
     */
    public function show($user_id)
    {
        $user = User::findOrFail($user_id);
        $wallet = HouseFundWallet::firstOrCreate([
            'user_id' => $user_id,
        ], [
            'balance' => 0.00,
            'monthly_contribution' => 0.00,
            'redeem_threshold' => 1000.00,
        ]);

        $contributions = HouseFundContribution::where('user_id', $user_id)->latest()->get();
        $redemptions = HouseFundRedemption::where('user_id', $user_id)->latest()->get();

        return view('admin.house_fund_wallet.show', compact('user', 'wallet', 'contributions', 'redemptions'));
    }

    /**
     * Display all contributions.
     */
    public function contributions()
    {
        $contributions = HouseFundContribution::with('user')->latest()->paginate(10);
        return view('admin.house_fund_wallet.contributions', compact('contributions'));
    }

    /**
     * Add a manual contribution.
     */
    public function addContribution(Request $request)
    {
        $request->validate([
            'user_id' => 'required|exists:users,id',
            'amount' => 'required|numeric|min:1',
        ]);

        HouseFundContribution::create([
            'user_id' => $request->user_id,
            'amount' => $request->amount,
        ]);

        // Update balance
        $wallet = HouseFundWallet::firstOrCreate(['user_id' => $request->user_id]);
        $wallet->increment('balance', $request->amount);

        return back()->with('success', 'Contribution added successfully.');
    }

    /**
     * Display all redemptions.
     */
    public function redemptions()
    {
        $redemptions = HouseFundRedemption::with('user')->latest()->paginate(10);
        return view('admin.house_fund_wallet.redemptions', compact('redemptions'));
    }

    /**
     * Approve a redemption request.
     */
    public function approveRedemption($id)
    {
        $redemption = HouseFundRedemption::findOrFail($id);
        $wallet = HouseFundWallet::where('user_id', $redemption->user_id)->first();

        if ($wallet && $wallet->balance >= $redemption->amount) {
            $wallet->decrement('balance', $redemption->amount);
            $redemption->update(['status' => 'approved']);
            return back()->with('success', 'Redemption approved successfully.');
        }

        return back()->with('error', 'Insufficient balance to approve redemption.');
    }

    /**
     * Reject a redemption request.
     */
    public function rejectRedemption($id)
    {
        $redemption = HouseFundRedemption::findOrFail($id);
        $redemption->update(['status' => 'rejected']);

        return back()->with('error', 'Redemption rejected.');
    }

    /**
     * Admin manually updates a user's balance.
     */
    public function updateBalance(Request $request)
    {
        $request->validate([
            'user_id' => 'required|exists:users,id',
            'balance' => 'required|numeric',
        ]);

        $wallet = HouseFundWallet::firstOrCreate(['user_id' => $request->user_id]);
        $wallet->update(['balance' => $request->balance]);

        return back()->with('success', 'Balance updated successfully.');
    }

    /**
     * Display settings page.
     */
    public function settings()
    {
        return view('admin.house_fund_wallet.settings');
    }

    /**
     * Update House Fund settings.
     */
    public function updateSettings(Request $request)
    {
        $request->validate([
            'redeem_threshold' => 'required|numeric|min:1',
        ]);

        config(['house_fund.redeem_threshold' => $request->redeem_threshold]);

        return back()->with('success', 'Settings updated successfully.');
    }
}
