<?php

namespace App\Http\Controllers;

use Illuminate\Http\Request;
use App\Models\Order;
use App\Models\OrderItem;
use Illuminate\Support\Facades\Config;
use App\Models\Product;
use App\Models\PaymentMethod;
use App\Models\Shipping;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\DB;

class CheckoutController extends Controller
{
    // 🍎 Load Checkout Page
    public function checkout()
    {
        $user = Auth::user();
        $cart = session()->get('cart', []);

        if (empty($cart)) {
            return back()->with('error', 'Your cart is empty!');
        }

        $total = collect($cart)->reduce(function ($carry, $item) {
            $product = Product::find($item['product_id'] ?? null);
            if (!$product) return $carry;

            $productPrice = $product->price - ($product->price * $product->discount / 100);
            return $carry + ($productPrice * ($item['quantity'] ?? 1));
        }, 0);

        // Apply user discount
        $discounts = ['basic' => 2, 'premium' => 5, 'vip' => 10];
        $discount = isset($user->plan) ? ($discounts[$user->plan->name] ?? 0) : 0;
        $totalDiscounted = $total - ($total * $discount / 100);

        // Active payment methods
        $paymentMethods = PaymentMethod::where('status', 'active')->get();

        // Country list & dial codes
        $countries = config('countries');
        $dialingCodes = config('dialing_codes');

        $pageTitle = "Checkout";

        return view('store.checkout', compact(
            'cart', 'total', 'discount', 'totalDiscounted', 'paymentMethods',
            'pageTitle', 'countries', 'dialingCodes'
        ));
    }

    // ✅ Process Order
    public function process(Request $request)
    {
        $user = Auth::user()->load('plan');
        $cart = session()->get('cart', []);

        if (empty($cart)) {
            return back()->with('error', 'Your cart is empty!');
        }

        // 🛡️ Validate Input
        $request->merge([
            'phone' => preg_replace('/^\+?[0-9]{1,4}/', '', $request->phone)
        ]);

        $request->validate([
            'country' => 'required|string|max:100',
            'first_name' => 'required|string|max:50',
            'last_name' => 'required|string|max:50',
            'phone' => 'required|string|max:20',
            'email' => 'required|email|max:100',
            'address' => 'required|string|max:255',
            'city' => 'required|string|max:100',
            'state' => 'required|string|max:100',
            'postal_code' => 'required|string|max:20',
            'payment_method' => 'required|exists:payment_methods,id',
            'total_price' => 'required|numeric|min:1',
        ]);

        DB::beginTransaction();
        try {
            // ✅ Save Shipping Info
            $shipping = Shipping::updateOrCreate(
                ['user_id' => $user->id],
                [
                    'first_name' => $request->first_name,
                    'last_name' => $request->last_name,
                    'phone' => $request->phone,
                    'email' => $request->email,
                    'address' => $request->address,
                    'city' => $request->city,
                    'state' => $request->state,
                    'postal_code' => $request->postal_code,
                    'country' => $request->country,
                ]
            );

            // ✅ Create Order
            $order = Order::create([
                'user_id' => $user->id,
                'shipping_id' => $shipping->id,
                'total_price' => $request->total_price,
                'payment_method' => $request->payment_method,
                'status' => 'pending',
                'tracking_code' => strtoupper(uniqid('ORD-')),
            ]);

            // ✅ Add Order Items and Reduce Stock
            foreach ($cart as $id => $item) {
                $product = Product::find($item['product_id'] ?? null);
                if (!$product) {
                    \Log::warning("Missing product in cart", ['product_id' => $item['product_id'] ?? 'N/A']);
                    continue;
                }

                OrderItem::create([
                    'order_id' => $order->id,
                    'product_id' => $product->id,
                    'quantity' => $item['quantity'],
                    'price' => $product->price,
                ]);

                $product->stock -= $item['quantity'];
                $product->save();
            }

            DB::commit();
            session()->forget('cart');

            return redirect()->route('user.orders')->with('success', 'Order placed successfully!');
        } catch (\Exception $e) {
            DB::rollback();
            return back()->with('error', 'Something went wrong! ' . $e->getMessage());
        }
    }

    // ✅ Order Tracking Page
    public function track(Request $request)
    {
        $request->validate([
            'tracking_code' => 'required|string',
        ]);

        $order = Order::where('tracking_code', $request->tracking_code)->first();

        if (!$order) {
            return back()->with('error', 'Order not found. Please check your tracking code.');
        }

        return view('store.track-order', compact('order'));
    }
}