<?php

namespace App\Http\Controllers;

use Illuminate\Http\Request;
use App\Models\Product;

class StoreController extends Controller
{
    /**
     * Display all products or a single product if product_id is provided.
     */
    public function index(Request $request)
    {
        $pageTitle = 'Store';

        if ($request->has('product_id')) {
            $product = Product::find($request->product_id);

            if (!$product) {
                abort(404, 'Product not found');
            }

            $relatedProducts = Product::where('id', '!=', $product->id)->take(4)->get();

            return view('store.index', [
                'pageTitle' => $product->name,
                'product' => $product,
                'relatedProducts' => $relatedProducts,
                'products' => Product::all(),
                'cart' => session('cart', [])
            ]);
        }

        return view('store.index', [
            'pageTitle' => $pageTitle,
            'products' => Product::all(),
            'cart' => session('cart', [])
        ]);
    }
    public function show($productId)
    {
        $product = Product::findOrFail($productId);
        $pageTitle = $product->name; // or "Product Details" or anything you like
    
        return view('store.index', compact('product', 'pageTitle'));
    }

    /**
     * Add a product to the cart.
     */
    public function addToCart(Request $request)
    {
        $cart = session()->get('cart', []);
    
        $product = Product::find($request->product_id);
        if (!$product) {
            return response()->json(['success' => false, 'message' => 'Product not found']);
        }
    
        // Check if product exists in cart
        if (isset($cart[$request->product_id])) {
            $cart[$request->product_id]['quantity'] += $request->quantity;
        } else {
            $cart[$request->product_id] = [
            'product_id' => $product->id, // ✅ required
            'name' => $product->name,
            'image' => $product->image,
            'price' => $product->price,
            'discount' => $product->discount, // ✅ optional, only if needed in checkout
            'quantity' => $request->quantity
        ];

        }
    
        session()->put('cart', $cart);
    
        return response()->json([
            'success' => true,
            'message' => 'Product added to cart',
            'cartCount' => count($cart),
            'cart' => $cart
        ]);
    }
    
    public function removeFromCart($id)
    {
        $cart = session()->get('cart', []);
    
        if (isset($cart[$id])) {
            unset($cart[$id]);
            session()->put('cart', $cart);
        }
    
        return response()->json([
            'success' => true,
            'message' => 'Item removed from cart',
            'cartCount' => count($cart),
            'cart' => $cart
        ]);
    }
    /**
     * Show cart page.
     */
    public function cart()
    {
        return view('store.cart', [
            'pageTitle' => 'Shopping Cart', 
            'cart' => session('cart', [])
        ]);
    }

    /**
     * Update cart quantity.
     */
    public function updateCart(Request $request, $id)
    {
        $cart = session()->get('cart', []);

        if (isset($cart[$id])) {
            $cart[$id]['quantity'] = $request->quantity;
            session()->put('cart', $cart);

            return redirect()->route('cart.index')->with('success', 'Cart updated successfully!');
        }

        return redirect()->route('cart.index')->with('error', 'Product not found in cart.');
    }

    /**
     * Get Cart Count for AJAX updates.
     */
    public function cartCount()
    {
        return response()->json(['count' => count(session('cart', []))]);
    }

    /**
     * Clear the cart.
     */
    public function clearCart()
    {
        session()->forget('cart');

        return redirect()->route('cart.index')->with('success', 'Cart cleared successfully!');
    }

    /**
     * Checkout Process (Redirect to login if not logged in).
     */
    public function checkout()
    {
        $cart = session('cart', []);
        $pageTitle = "Checkout"; // Define the page title
        if (!auth()->check()) {
            return redirect()->route('login')->with('error', 'You need to login first.');
        }

        $cart = session()->get('cart', []);

        if (empty($cart)) {
            return redirect()->route('store.index')->with('error', 'Your cart is empty.');
        }

        return view('store.checkout', compact('cart', 'pageTitle'));
    }
}
