<?php

namespace App\Http\Controllers\User;

use App\Http\Controllers\Controller;
use Illuminate\Http\Request;
use App\Models\HouseFundWallet;
use App\Models\HouseFundContribution;
use App\Models\HouseFundRedemption;
use Illuminate\Support\Facades\Auth;
use App\Models\Setting;
use Illuminate\Support\Facades\DB;

class HouseFundController extends Controller
{
    /**
     * Display the House Fund Wallet page.
     */
    public function housefundIndex()
    {
        $user = auth()->user();

        // ✅ Fetch wallet without resetting balance
        $wallet = HouseFundWallet::where('user_id', $user->id)->first();

        if (!$wallet) {
            $wallet = HouseFundWallet::create([
                'user_id' => $user->id,
                'balance' => 0.00, // Ensure admin-set balances are preserved
                'monthly_contribution' => 0.00,
                'redeem_threshold' => Setting::where('key', 'house_fund.redeem_threshold')->value('value') ?? 1000.00,
            ]);
        }

        // ✅ Fetch Monthly Contributions
        $monthlyContributions = HouseFundContribution::where('user_id', $user->id)->latest()->get();

        // ✅ Fetch Redemption History
        $redemptionHistory = HouseFundRedemption::where('user_id', $user->id)->latest()->get();

        // ✅ Update balance correctly (Preserve Admin Updates)
        $wallet->updateBalance();

        // ✅ Define Page Title (to prevent undefined variable errors)
        $pageTitle = "My House Fund Wallet";

        return view('templates.basic.user.house_fund_wallet', compact('wallet', 'monthlyContributions', 'redemptionHistory', 'pageTitle'));
    }

    /**
     * Redeem House Fund balance if conditions are met.
     */
    public function redeem(Request $request)
    {
        $request->validate([
            'amount' => 'required|numeric|min:1',
        ]);

        $user = Auth::user();
        $wallet = HouseFundWallet::where('user_id', $user->id)->first();

        if (!$wallet) {
            return back()->with('error', 'No wallet found.');
        }

        // Ensure balance is updated before checking eligibility
        $wallet->updateBalance();

        // Ensure requested amount is valid
        $amount = $request->amount;
        if ($amount > $wallet->balance) {
            return back()->with('error', 'You cannot redeem more than your balance.');
        }

        if ($wallet->balance < $wallet->redeem_threshold) {
            return back()->with('error', 'Balance is below the redemption threshold.');
        }

        try {
            // Store redemption request (DO NOT deduct balance yet)
            HouseFundRedemption::create([
                'user_id' => $user->id,
                'amount' => $amount, // Use user-defined amount instead of full balance
                'status' => 'pending', // Waiting for admin approval
            ]);

            return back()->with('success', 'Redemption request submitted for approval.');
        } catch (\Exception $e) {
            return back()->with('error', 'An error occurred while redeeming funds.');
        }
    }
}
