<?php

namespace App\Http\Controllers\User;

use App\Constants\Status;
use App\Http\Controllers\Controller;
use App\Http\Controllers\Gateway\PaymentController;
use App\Lib\Mlm;
use App\Models\GatewayCurrency;
use App\Models\Plan;
use Illuminate\Http\Request;

class PlanController extends Controller
{
    function planIndex()
    {
        $pageTitle = "Plans";
        $plans = Plan::where('status', Status::ENABLE)->orderBy('price', 'asc')->paginate(getPaginate(15));
        $gatewayCurrency = GatewayCurrency::whereHas('method', function ($gate) {
            $gate->where('status', Status::ENABLE);
        })->with('method')->orderby('name')->get();
        return view('Template::user.plan', compact('pageTitle', 'plans', 'gatewayCurrency'));
    }

    function planPurchase(Request $request)
    {
        $request->validate([
            'id' => 'required',
            'gateway' => 'required'
        ]);

        $plan = Plan::where('status', Status::ENABLE)->findOrFail($request->id);
        $user = auth()->user();

        if ($user->plan_id && $user->plan->price > $plan->price) {
            return back()->with('error', 'Plan cannot be downgraded.');
        }

        if ($request->gateway != 'wallet') {
            $gate = GatewayCurrency::whereHas('method', function ($gate) {
                $gate->where('status', Status::ENABLE);
            })->where('method_code', $request->gateway)->first();

            if (!$gate) {
                return back()->with('error', 'Invalid gateway.');
            }

            if ($gate->min_amount > $plan->price || $gate->max_amount < $plan->price) {
                return back()->with('error', 'Plan price exceeds gateway limits.');
            }

            $data = PaymentController::insertDeposit($gate, $plan->price, $plan);
            session()->put('Track', $data->trx);
            return to_route('user.deposit.confirm');
        }

        if ($user->balance < $plan->price) {
            return back()->with('error', 'Insufficient balance.');
        }

        // Generate transaction ID
        $trx = getTrx();

        // Process MLM Plan Purchase
        $mlm = new Mlm($user, $plan, $trx);
        $mlm->purchasePlan();

        // ✅ Apply Plan Benefits
        $this->applyPlanBenefits($user, $plan);

        return to_route("user.plan.index")->with('success', ucfirst($plan->name) . ' plan purchased successfully.');
    }

    /**
     * Apply plan benefits to the user
     */
    private function applyPlanBenefits($user, $plan)
    {
        $user->plan_id = $plan->id;
        $user->bv = $plan->bv;
        $user->ref_com = $plan->ref_com;
        $user->max_pairs_per_day = $plan->max_pairs_per_day;
        $user->infinite_pairs = $plan->infinite_pairs;
        $user->product_share_limit = $plan->product_share_limit;
        $user->product_share_com = $plan->product_share_com;

        $user->save();
    }
}
