<?php

namespace App\Http\Controllers\User;

use App\Http\Controllers\Controller;
use Illuminate\Http\Request;
use App\Models\User;
use App\Models\Transaction;
use App\Models\Withdrawal;
use App\Models\Deposit;
use Illuminate\Support\Facades\Auth;
use App\Constants\Status;

class WalletController extends Controller
{
    /**
     * Display the user's wallet balance and transaction history.
     */
    public function index()
    {
        $user = Auth::user();
        $transactions = Transaction::where('user_id', $user->id)
            ->orderBy('created_at', 'desc')
            ->paginate(10);

        return view('user.wallet.index', compact('user', 'transactions'));
    }

    /**
     * Handle deposits into user wallet.
     */
    public function deposit(Request $request)
    {
        $request->validate([
            'amount' => 'required|numeric|min:10', // Minimum deposit amount
        ]);

        $user = Auth::user();
        $amount = $request->amount;

        // Create a new deposit record
        $deposit = new Deposit();
        $deposit->user_id = $user->id;
        $deposit->amount = $amount;
        $deposit->status = Status::PAYMENT_SUCCESS;
        $deposit->trx = getTrx();
        $deposit->save();

        // Update user wallet balance
        $user->balance += $amount;
        $user->save();

        // Create a transaction log
        Transaction::create([
            'user_id' => $user->id,
            'amount' => $amount,
            'post_balance' => $user->balance,
            'trx_type' => '+',
            'remark' => 'Deposit into Wallet',
            'trx' => $deposit->trx,
        ]);

        return back()->with('success', 'Deposit added successfully.');
    }

    /**
     * Handle withdrawals from user wallet.
     */
    public function withdraw(Request $request)
    {
        $request->validate([
            'amount' => 'required|numeric|min:10',
            'method' => 'required|string',
        ]);

        $user = Auth::user();
        $amount = $request->amount;

        if ($user->balance < $amount) {
            return back()->with('error', 'Insufficient wallet balance.');
        }

        // Deduct from user balance
        $user->balance -= $amount;
        $user->save();

        // Create withdrawal record
        Withdrawal::create([
            'user_id' => $user->id,
            'amount' => $amount,
            'method' => $request->method,
            'status' => Status::PAYMENT_PENDING,
            'trx' => getTrx(),
        ]);

        // Create transaction record
        Transaction::create([
            'user_id' => $user->id,
            'amount' => $amount,
            'post_balance' => $user->balance,
            'trx_type' => '-',
            'remark' => 'Wallet Withdrawal Request',
            'trx' => getTrx(),
        ]);

        return back()->with('success', 'Withdrawal request submitted successfully.');
    }
}
