<?php 

namespace App\Models;

use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Database\Eloquent\Model;

class HouseFundWallet extends Model
{
    use HasFactory;

    protected $fillable = ['user_id', 'balance', 'monthly_contribution', 'redeem_threshold'];

    protected $attributes = [
        'balance' => 0.00,
        'monthly_contribution' => 0.00,
        'redeem_threshold' => 1000.00, // Default threshold for redemption
    ];

    /**
     * Define relationship with User model.
     */
    public function user()
    {
        return $this->belongsTo(User::class)->withDefault([
            'name' => 'N/A'
        ]);
    }

    /**
     * Get the user's monthly contributions.
     */
    public function contributions()
    {
        return $this->hasMany(HouseFundContribution::class, 'user_id', 'user_id')->latest();
    }

    /**
     * Get the user's redemption history.
     */
    public function redemptions()
    {
        return $this->hasMany(HouseFundRedemption::class, 'user_id', 'user_id')->latest();
    }

    /**
     * Ensure a user always has a wallet.
     */
    public static function getOrCreateWallet($user_id)
    {
        return self::firstOrCreate(
            ['user_id' => $user_id],
            ['balance' => 0.00, 'monthly_contribution' => 0.00, 'redeem_threshold' => 1000.00]
        );
    }

    /**
     * Check if the user is eligible for redemption.
     */
    public function canRedeem(): bool
    {
        return $this->balance >= $this->redeem_threshold;
    }

    /**
     * ✅ Fix: Ensure the balance does NOT reset when a user logs in.
     */
    public function updateBalance()
    {
        $totalContributions = $this->contributions()->sum('amount');
        $totalRedemptions = $this->redemptions()->where('status', 'approved')->sum('amount');

        // ✅ Calculate expected balance
        $calculatedBalance = max(0, $totalContributions - $totalRedemptions);

        // ✅ Prevent overriding admin-set balances
        if ($this->balance === 0.00 || $this->balance === null) {
            // If balance is empty (first time login), update it
            $this->balance = $calculatedBalance;
            $this->save();
        } elseif ($this->balance < $calculatedBalance) {
            // If the user contributes and increases the balance, update it
            $this->balance = $calculatedBalance;
            $this->save();
        }

        // ✅ Sync to User table if necessary
        if ($this->user) {
            $this->user->balance = $this->balance;
            $this->user->save();
        }
    }
}
