<?php

namespace App\Services;

use App\Models\HouseFundWallet;
use App\Models\User;
use Illuminate\Support\Facades\DB;

class HouseFundWalletService {
    protected $contributionRate = 5; // 5% of earnings
    protected $defaultThreshold = 1000; // Default redeem threshold

    /**
     * Process the monthly contribution of a user.
     *
     * @param User $user
     * @param float $earnings
     * @return string
     */
    public function processMonthlyContribution(User $user, float $earnings): string {
        return DB::transaction(function () use ($user, $earnings) {
            $contribution = ($earnings * $this->contributionRate) / 100;

            // Ensure the wallet exists and has a redeem_threshold
            $wallet = HouseFundWallet::firstOrCreate(
                ['user_id' => $user->id],
                ['redeem_threshold' => $this->defaultThreshold]
            );

            // Increment balance and monthly contribution
            $wallet->increment('balance', $contribution);
            $wallet->increment('monthly_contribution', $contribution);

            return "Contribution of $contribution added successfully.";
        }, 3); // Retry transaction up to 3 times in case of failure
    }

    /**
     * Redeem funds for a user if eligible.
     *
     * @param User $user
     * @return string
     */
    public function redeemFunds(User $user): string {
        return DB::transaction(function () use ($user) {
            $wallet = HouseFundWallet::where('user_id', $user->id)->first();

            if (!$wallet) {
                return "Wallet not found for user ID: {$user->id}.";
            }

            if ($wallet->balance < $wallet->redeem_threshold) {
                return "Not eligible for redemption. Minimum required: {$wallet->redeem_threshold}, Current Balance: {$wallet->balance}.";
            }

            // Reset the balance and monthly contribution after redemption
            $wallet->update(['balance' => 0, 'monthly_contribution' => 0]);

            return "Funds successfully redeemed.";
        });
    }
}
